Learn R Programming

multgee (version 1.3)

intrinsic.pars: Intrinsic Parameters Estimation

Description

Utility function to assess the underlying association pattern.

Usage

intrinsic.pars(response, id, repeated, ncategories, rscale = "ordinal")

Arguments

response
a vector that indicates the response variables.
id
a vector that identifies the clusters.
repeated
a vector that identifies the order of the observations within each cluster.
ncategories
a positive constant that indicates the number of observed response categories.
rscale
a character string that indicates the nature of the response scale. Options include "ordinal" or "nominal".

Value

  • Returns a numerical vector with the estimated intrinsic parameters.

Details

Simulation studies in Touloumis et al. (2013) suggested that if the range of the intrinsic parameter estimates is small then simple local odds ratios structures should adequately approximate the association pattern. Otherwise more complicated structures should be employed. The intrinsic parameters are estimated under the heterogeneous linear-by-linear association model (Agresti, 2013) for ordinal response categories and under the RC-G(1) model (Becker and Clogg, 1989) with homogeneous score parameters for nominal response categories.

References

Agresti, A. (2013). Categorical Data Analysis. New York: John Wiley and Sons, Inc., 3rd Edition. Becker, M. and Clogg, C. (1989). Analysis of sets of two-way contingency tables using association models. Journal of the American Statistical Association, 84, 142-151. Touloumis, A., Agresti, A. and Kateri, M. (2013). GEE for multinomial responses using a local odds ratios parameterization. Biometrics.

See Also

nomLORgee and ordLORgee.

Examples

Run this code
data(arthritis)
intrinsic.pars(arthritis$y,arthritis$id,arthritis$time,5)
## The intrinsic parameters do not differ much. The 'uniform' local odds ratios
## structure might be a good approximation for the association pattern.

set.seed(1)
data(housing)
intrinsic.pars(housing$y,housing$id,housing$time,3,rscale="nominal")
## The intrinsic parameters vary. The 'RC' local odds ratios structure
## might be a good approximation for the association pattern.

Run the code above in your browser using DataLab